pub struct PostMergeContext { /* private fields */ }Expand description
Context provided to post-merge hooks.
Contains metadata about the merge process that hooks may use for
decision-making or diagnostics. The context is constructed by the
generated merge code and passed to PostMergeHook::post_merge.
Examples
use ortho_config::PostMergeContext;
use camino::Utf8PathBuf;
let mut ctx = PostMergeContext::new("APP_");
ctx.with_file(Utf8PathBuf::from("/etc/app/config.toml"))
.with_cli_input();
assert_eq!(ctx.prefix(), "APP_");
assert!(ctx.has_cli_input());
assert_eq!(ctx.loaded_files().len(), 1);Implementations
Sourceimpl PostMergeContext
impl PostMergeContext
Sourcepub fn new(prefix: impl Into<String>) -> Self
pub fn new(prefix: impl Into<String>) -> Self
Creates a new context with the given prefix.
Examples
use ortho_config::PostMergeContext;
let ctx = PostMergeContext::new("MY_APP_");
assert_eq!(ctx.prefix(), "MY_APP_");Sourcepub fn with_file(&mut self, path: Utf8PathBuf) -> &mut Self
pub fn with_file(&mut self, path: Utf8PathBuf) -> &mut Self
Adds a loaded file path to the context.
Examples
use ortho_config::PostMergeContext;
use camino::Utf8PathBuf;
let mut ctx = PostMergeContext::new("APP_");
ctx.with_file(Utf8PathBuf::from("/etc/app.toml"));
assert_eq!(ctx.loaded_files().len(), 1);Sourcepub fn with_cli_input(&mut self) -> &mut Self
pub fn with_cli_input(&mut self) -> &mut Self
Marks that CLI input was present in the merge.
Examples
use ortho_config::PostMergeContext;
let mut ctx = PostMergeContext::new("APP_");
ctx.with_cli_input();
assert!(ctx.has_cli_input());Sourcepub fn prefix(&self) -> &str
pub fn prefix(&self) -> &str
Returns the prefix used during configuration loading.
Examples
use ortho_config::PostMergeContext;
let ctx = PostMergeContext::new("MY_APP_");
assert_eq!(ctx.prefix(), "MY_APP_");Sourcepub fn loaded_files(&self) -> &[Utf8PathBuf]
pub fn loaded_files(&self) -> &[Utf8PathBuf]
Returns the paths of configuration files that contributed to the merge.
Examples
use ortho_config::PostMergeContext;
use camino::Utf8PathBuf;
let mut ctx = PostMergeContext::new("APP_");
ctx.with_file(Utf8PathBuf::from("/etc/app.toml"))
.with_file(Utf8PathBuf::from("~/.config/app.toml"));
assert_eq!(ctx.loaded_files().len(), 2);Sourcepub const fn has_cli_input(&self) -> bool
pub const fn has_cli_input(&self) -> bool
Returns whether CLI arguments were present in the merge.
Examples
use ortho_config::PostMergeContext;
let ctx_without_cli = PostMergeContext::new("APP_");
assert!(!ctx_without_cli.has_cli_input());
let mut ctx_with_cli = PostMergeContext::new("APP_");
ctx_with_cli.with_cli_input();
assert!(ctx_with_cli.has_cli_input());Trait Implementations
Sourceimpl Clone for PostMergeContext
impl Clone for PostMergeContext
Sourcefn clone(&self) -> PostMergeContext
fn clone(&self) -> PostMergeContext
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PostMergeContext
impl Debug for PostMergeContext
Sourceimpl Default for PostMergeContext
impl Default for PostMergeContext
Sourcefn default() -> PostMergeContext
fn default() -> PostMergeContext